@@ -4,9 +4,11 @@
  *  License: MIT (See the LICENSE file in the repository root directory)
  */
 
+use cli::SetUp;
 use structopt::StructOpt;
 
 pub mod cli;
+pub mod config;
 pub mod constants;
 pub mod error;
 pub mod file_handler;
@@ -21,6 +23,8 @@ use crate::cli::Opt;
 use exitfailure::ExitFailure;
 
 fn main() -> Result<(), ExitFailure> {
+    config::scheme::load_default_config();
+
     let opt = Opt::from_args();
 
     #[cfg(windows)]
@@ -119,6 +123,16 @@ fn main() -> Result<(), ExitFailure> {
             break_bad,
             save_out,
         } => subcommand::cmd_run::run(target_file, &prefix[..], timeout, break_bad, save_out),
+        Opt::Setup { subcommand } => match subcommand {
+            SetUp::Cpp {
+                program,
+                standard,
+                flags,
+            } => subcommand::cmd_setup::setup_cpp(&program[..], &standard[..], &flags[..]),
+            SetUp::Python { program, flags } => {
+                subcommand::cmd_setup::setup_python(&program[..], &flags[..])
+            }
+        },
         Opt::Example { cmp, tle, check } => subcommand::cmd_example::run(cmp, tle, check),
     }
 }
